##  Introduction
System for Cross-domain Identity Management (SCIM) is a standard protocol designed to automate the synchronization of user states across multiple systems. SCIM facilitates the transfer of user information from a source system, such as an external identity provider (IdP), to a target system, such as SAP LeanIX.
In SAP LeanIX, SCIM works together with single sign-on (SSO). SCIM is used to automate the process of user provisioning and deprovisioning across multiple systems, while SSO is used for authentication and authorization. During the sign-in process, SSO checks if a user has the right to access the system (known as authentication) and determines the user's permissions within the system (known as authorization). For more information, see [Single Sign-On (SSO)](https://help.sap.com/docs/leanix/ea/single-sign-on-sso?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to configure single sign-on \(SSO\) with SAP LeanIX.").
SCIM is used for the following purposes:
  * User provisioning: Provisioning means creating a user account. If a user exists in the source system, such as an external IdP, but not in the target system (SAP LeanIX), then a corresponding user object is created in the target system.
  * User deprovisioning: Deprovisioning means archiving a user account. If a user exists in the target system but not in the source system, then the user object in the target system gets deprovisioned.
  * User updating: If the user data in the source system differs from the data in the target system, then this data is transferred to the target system.
